@@ -1,6 +1,6 @@
 /***************************************************************************
           MessageBox.cpp -  threasafe wrapper for KMessageBox
-			     -------------------
+                             -------------------
     begin                : Sun Apr 13 2008
     copyright            : (C) 2008 by Thomas Eschenbacher
     email                : Thomas.Eschenbacher@gmx.de
@@ -38,17 +38,17 @@ Kwave::MessageBox::MessageBox(KMessageBox::DialogType mode, QWidget *parent,
      m_dont_ask_again_name(dontAskAgainName)
 {
     if (QThread::currentThread() == QApplication::instance()->thread()) {
-	// we are already in the GUI thread -> direct call
-	show();
+        // we are already in the GUI thread -> direct call
+        show();
     } else {
-	// schedule execution in the GUI thread ...
-	Trigger *trigger = new(std::nothrow) Trigger(*this);
-	Q_ASSERT(trigger);
-	if (!trigger) return;
-	trigger->deleteLater();
+        // schedule execution in the GUI thread ...
+        Trigger *trigger = new(std::nothrow) Trigger(*this);
+        Q_ASSERT(trigger);
+        if (!trigger) return;
+        trigger->deleteLater();
 
-	// ... and wait
-	m_semaphore.acquire();
+        // ... and wait
+        m_semaphore.acquire();
     }
 }
 
@@ -69,9 +69,9 @@ int Kwave::MessageBox::questionYesNo(QWidget *parent,
     const QString buttonYes, const QString buttonNo,
     const QString &dontAskAgainName)
 {
-    return Kwave::MessageBox::exec(KMessageBox::QuestionYesNo,
-	parent, message, caption, buttonYes, buttonNo,
-	dontAskAgainName);
+    return Kwave::MessageBox::exec(KMessageBox::QuestionTwoActions,
+        parent, message, caption, buttonYes, buttonNo,
+        dontAskAgainName);
 }
 
 //***************************************************************************
@@ -80,17 +80,17 @@ int Kwave::MessageBox::questionYesNoCancel(QWidget *parent,
     const QString buttonYes, const QString buttonNo,
     const QString &dontAskAgainName)
 {
-    return Kwave::MessageBox::exec(KMessageBox::QuestionYesNoCancel,
-	parent, message, caption, buttonYes, buttonNo,
-	dontAskAgainName);
+    return Kwave::MessageBox::exec(KMessageBox::QuestionTwoActionsCancel,
+        parent, message, caption, buttonYes, buttonNo,
+        dontAskAgainName);
 }
 
 //***************************************************************************
 int Kwave::MessageBox::sorry(QWidget *parent,
     QString message, QString caption)
 {
-    return Kwave::MessageBox::exec(KMessageBox::Sorry,
-	parent, message, caption);
+    return Kwave::MessageBox::exec(KMessageBox::Error,
+        parent, message, caption);
 }
 
 //***************************************************************************
@@ -99,9 +99,9 @@ int Kwave::MessageBox::warningYesNo(QWidget *parent,
     const QString buttonYes, const QString buttonNo,
     const QString &dontAskAgainName)
 {
-    return Kwave::MessageBox::exec(KMessageBox::WarningYesNo,
-	parent, message, caption, buttonYes, buttonNo,
-	dontAskAgainName);
+    return Kwave::MessageBox::exec(KMessageBox::WarningTwoActions,
+        parent, message, caption, buttonYes, buttonNo,
+        dontAskAgainName);
 }
 
 //***************************************************************************
@@ -110,9 +110,9 @@ int Kwave::MessageBox::warningYesNoCancel(QWidget *parent,
     const QString buttonYes, const QString buttonNo,
     const QString &dontAskAgainName)
 {
-    return Kwave::MessageBox::exec(KMessageBox::WarningYesNoCancel,
-	parent, message, caption, buttonYes, buttonNo,
-	dontAskAgainName);
+    return Kwave::MessageBox::exec(KMessageBox::WarningTwoActionsCancel,
+        parent, message, caption, buttonYes, buttonNo,
+        dontAskAgainName);
 }
 
 //***************************************************************************
@@ -122,8 +122,8 @@ int Kwave::MessageBox::warningContinueCancel(QWidget *parent,
     const QString &dontAskAgainName)
 {
     return Kwave::MessageBox::exec(KMessageBox::WarningContinueCancel,
-	parent, message, caption, buttonContinue, buttonCancel,
-	dontAskAgainName);
+        parent, message, caption, buttonContinue, buttonCancel,
+        dontAskAgainName);
 }
 
 //***************************************************************************
@@ -131,7 +131,7 @@ int Kwave::MessageBox::error(QWidget *parent,
     QString message, QString caption)
 {
     return Kwave::MessageBox::exec(KMessageBox::Error,
-	parent, message, caption);
+        parent, message, caption);
 }
 
 //***************************************************************************
@@ -141,9 +141,9 @@ int Kwave::MessageBox::exec(KMessageBox::DialogType mode, QWidget *parent,
     const QString &dontAskAgainName)
 {
     Kwave::MessageBox box(
-	mode, parent, message, caption,
-	button1, button2,
-	dontAskAgainName
+        mode, parent, message, caption,
+        button1, button2,
+        dontAskAgainName
     );
     return box.retval();
 }
@@ -152,87 +152,77 @@ int Kwave::MessageBox::exec(KMessageBox::DialogType mode, QWidget *parent,
 KGuiItem Kwave::MessageBox::yes()
 {
     return KGuiItem(QApplication::translate("KStandardGuiItem", "&Yes"),
-	            QStringLiteral("dialog-ok"));
+                    QStringLiteral("dialog-ok"));
 }
 
 //***************************************************************************
 KGuiItem Kwave::MessageBox::no()
 {
     return KGuiItem(QApplication::translate("KStandardGuiItem", "&No"),
-	            QStringLiteral("dialog-cancel"));
+                    QStringLiteral("dialog-cancel"));
 }
 
 //***************************************************************************
 void Kwave::MessageBox::show()
 {
     switch (m_mode) {
-	// QuestionYesNo
-	case KMessageBox::QuestionYesNo:
-	    m_retval = KMessageBox::questionTwoActions(m_parent,
-		m_message, m_caption,
-		(!m_button1.isEmpty()) ? KGuiItem(m_button1) :
-		                         Kwave::MessageBox::yes(),
-		(!m_button2.isEmpty()) ? KGuiItem(m_button2) :
-		                         Kwave::MessageBox::no(),
-		m_dont_ask_again_name);
-	    break;
-	// QuestionYesNoCancel
-	case KMessageBox::QuestionYesNoCancel:
-	    m_retval = KMessageBox::questionTwoActionsCancel(m_parent,
-		m_message, m_caption,
-		(!m_button1.isEmpty()) ? KGuiItem(m_button1) :
-		                         Kwave::MessageBox::yes(),
-		(!m_button2.isEmpty()) ? KGuiItem(m_button2) :
-		                         Kwave::MessageBox::no(),
-		KStandardGuiItem::cancel(),
-		m_dont_ask_again_name);
-	    break;
-	// Sorry
-	case KMessageBox::Sorry:
-	    KMessageBox::error(m_parent, m_message, m_caption);
-	    break;
-	// WarningYesNoCancel
-	case KMessageBox::WarningYesNoCancel:
-	    m_retval = KMessageBox::warningTwoActionsCancel(m_parent,
-		m_message, m_caption,
-		(!m_button1.isEmpty()) ? KGuiItem(m_button1) :
-		                         Kwave::MessageBox::yes(),
-		(!m_button2.isEmpty()) ? KGuiItem(m_button2) :
-		                         Kwave::MessageBox::no(),
-		KStandardGuiItem::cancel(),
-		m_dont_ask_again_name);
-	    break;
-	// WarningYesNo
-	case KMessageBox::WarningYesNo:
-	    m_retval = KMessageBox::warningTwoActions(m_parent,
-		m_message, m_caption,
-		(!m_button1.isEmpty()) ? KGuiItem(m_button1) :
-		                         Kwave::MessageBox::yes(),
-		(!m_button2.isEmpty()) ? KGuiItem(m_button2) :
-		                         Kwave::MessageBox::no(),
-		m_dont_ask_again_name);
-	    break;
-	// WarningContinueCancel
-	case KMessageBox::WarningContinueCancel:
-	    m_retval = KMessageBox::warningContinueCancel(m_parent,
-		m_message, m_caption,
-		(!m_button1.isEmpty()) ? KGuiItem(m_button1) :
-		                         KStandardGuiItem::cont(),
-		(!m_button2.isEmpty()) ? KGuiItem(m_button2) :
-		                         KStandardGuiItem::cancel(),
-		m_dont_ask_again_name);
-	    break;
-	// Error
-	case KMessageBox::Error:
-	    KMessageBox::error(m_parent, m_message, m_caption);
-	    break;
-	case KMessageBox::Information:
-	    KMessageBox::information(m_parent, m_message, m_caption,
-	                             m_dont_ask_again_name);
-	    break;
-	default:
-	    qWarning("unsupported messagebox mode");
-	    Q_ASSERT(0);
+        case KMessageBox::QuestionTwoActions:
+            m_retval = KMessageBox::questionTwoActions(m_parent,
+                m_message, m_caption,
+                (!m_button1.isEmpty()) ? KGuiItem(m_button1) :
+                                         Kwave::MessageBox::yes(),
+                (!m_button2.isEmpty()) ? KGuiItem(m_button2) :
+                                         Kwave::MessageBox::no(),
+                m_dont_ask_again_name);
+            break;
+        case KMessageBox::QuestionTwoActionsCancel:
+            m_retval = KMessageBox::questionTwoActionsCancel(m_parent,
+                m_message, m_caption,
+                (!m_button1.isEmpty()) ? KGuiItem(m_button1) :
+                                         Kwave::MessageBox::yes(),
+                (!m_button2.isEmpty()) ? KGuiItem(m_button2) :
+                                         Kwave::MessageBox::no(),
+                KStandardGuiItem::cancel(),
+                m_dont_ask_again_name);
+            break;
+        case KMessageBox::WarningTwoActionsCancel:
+            m_retval = KMessageBox::warningTwoActionsCancel(m_parent,
+                m_message, m_caption,
+                (!m_button1.isEmpty()) ? KGuiItem(m_button1) :
+                                         Kwave::MessageBox::yes(),
+                (!m_button2.isEmpty()) ? KGuiItem(m_button2) :
+                                         Kwave::MessageBox::no(),
+                KStandardGuiItem::cancel(),
+                m_dont_ask_again_name);
+            break;
+        case KMessageBox::WarningTwoActions:
+            m_retval = KMessageBox::warningTwoActions(m_parent,
+                m_message, m_caption,
+                (!m_button1.isEmpty()) ? KGuiItem(m_button1) :
+                                         Kwave::MessageBox::yes(),
+                (!m_button2.isEmpty()) ? KGuiItem(m_button2) :
+                                         Kwave::MessageBox::no(),
+                m_dont_ask_again_name);
+            break;
+        case KMessageBox::WarningContinueCancel:
+            m_retval = KMessageBox::warningContinueCancel(m_parent,
+                m_message, m_caption,
+                (!m_button1.isEmpty()) ? KGuiItem(m_button1) :
+                                         KStandardGuiItem::cont(),
+                (!m_button2.isEmpty()) ? KGuiItem(m_button2) :
+                                         KStandardGuiItem::cancel(),
+                m_dont_ask_again_name);
+            break;
+        case KMessageBox::Error:
+            KMessageBox::error(m_parent, m_message, m_caption);
+            break;
+        case KMessageBox::Information:
+            KMessageBox::information(m_parent, m_message, m_caption,
+                                     m_dont_ask_again_name);
+            break;
+        default:
+            qWarning("unsupported messagebox mode");
+            Q_ASSERT(0);
     }
 
     m_semaphore.release();
